ColorBlobConfig class

Configuration for color blobs

Constructors

ColorBlobConfig({ColorBlobPosition position = ColorBlobPosition.topLeft, double size = 150.0, double colorOffset = 0.0, double blurSigma = 10.0, double scale = 0.6, double floatMultiplier = 1.0, double opacity = 0.8})
const

Properties

blurSigma → double
final
colorOffset → double
final
floatMultiplier → double
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → double
final
position → ColorBlobPosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
size → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited